# ykenan_util

> **`File read and write operations`**

This is a simple log package. You can see
[Github-ykenan_util](https://github.com/YuZhengM/ykenan_util)
[PyPI-ykenan_util](https://pypi.org/project/ykenan_util/)

## Use

> install

```shell
pip install ykenan_util
```

> import

```shell
import ykenan_util as yu
```

